(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     53271,       1586]*)
(*NotebookOutlinePosition[     54434,       1623]*)
(*  CellTagsIndexPosition[     54390,       1619]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Force Computation with Radia",
  FontSize->24]], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
March 1999
Pascal Elleaume\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "-  The force and torque computation can be made using the functions \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  "radFldEnrFrc",
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  "radFldEnrTrq",
  StyleBox["\". ",
    Evaluatable->False,
    AspectRatioFixed->True],
  "For more information on the arguments of  radFldEnrFrc, type \
\"?radFldEnrFrc\" in a mathematica notebook or look at the documentation \
included in the Radia distribution. The function \"rad FldEnrFrc\" ",
  StyleBox[
  " computes  the variation of the interaction energy  between the source and \
the destination object for two positions of the destination object. The \
destination object is subdivided into many elements and the force and torque \
is summed up  over each sub-element.  The force and torque computation \
requires a lot of cpu processing. For densly packed objects,  while it may be \
easy to reach a 10% precision, one may run out of memory  if one looks for a \
precision of  1%. If the source and destination object are far apart from \
each other the required segmentation of the destination object is low and the \
computation converges very rapidly. In this notebook we compute the force and \
torque induced by two permanent magnets (green in the graphics) acting on \
another magnet  (red) located at a short distance away. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Creating the Model", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
(* Load Radia *)
<<Radia`;\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Radia Version: \"\>", "\[InvisibleSpace]", 
        StyleBox["4.0940000000000003`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], "\[InvisibleSpace]", "\<\" is loaded\"\>"}],
      SequenceForm[ "Radia Version: ", 4.0940000000000003, " is loaded"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Radia is copyright ESRF, Grenoble France \nPortions copyright 1997 \
Wolfram Research, Inc."\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(radUtiDelAll[]; \ \  (*\ to\ recover\ all\ memory\ *) \n\n
    p1 = {10, \(-20\), 0}; w1 = {10, 15, 14}; m1 = {0, 1, 0}; \n
    ga = radObjRecMag[p1, w1, m1]; \ngb = radObjRecMag[\(-p1\), w1, \(-m1\)]; 
    \ng1 = radObjCnt[{ga, gb}]; \nradObjDrwAtr[g1, {0, 1, 0.5}]; \n\n
    p2 = {0, 0, 0}; w2 = {30, 25, 10}; m2 = {0, 0, 1}; \n
    g2 = radObjRecMag[p2, w2, m2]; radObjDrwAtr[g2, {1, 0, 0.5}]; \n\n
    g = radObjCnt[{g1, g2}]; \n\nRadPlot3DOptions[]; \n
    Show[Graphics3D[radObjDrw[g]]]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.77491 .71611 -11.7926 0 ]
[.77491 .71611 12.4574 14 ]
[.8535 .67986 -4.8231 0 ]
[.8535 .67986 5.1769 14 ]
[.93718 .64126 -7.6486 0 ]
[.93718 .64126 8.3514 14 ]
[.85571 .74232 -7.5361 0 ]
[.85571 .74232 8.0889 14 ]
[.34782 .2463 -11.932 -14 ]
[.34782 .2463 12.318 0 ]
[.61965 .30877 -5.06218 -14 ]
[.61965 .30877 4.93782 0 ]
[.87104 .36656 -8.3067 -14 ]
[.87104 .36656 7.6933 0 ]
[.61887 .24628 -7.90966 -14 ]
[.61887 .24628 7.71534 0 ]
[.00657 .42571 -18.25 -8.37195 ]
[.00657 .42571 0 5.62805 ]
[.00316 .49436 -10 -8.30561 ]
[.00316 .49436 0 5.69439 ]
[-0.00029 .56399 -10 -8.23839 ]
[-0.00029 .56399 0 5.76161 ]
[-0.05828 .4829 -14.3125 -8.30561 ]
[-0.05828 .4829 0 5.69439 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.73157 .72348 m
.98719 .60542 L
s
.25 Mabswid
.77457 .70362 m
.7744 .69737 L
s
gsave
.77491 .71611 -72.7926 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.85306 .66737 m
.85284 .66112 L
s
gsave
.8535 .67986 -65.8231 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.93663 .62877 m
.93636 .62252 L
s
gsave
.93718 .64126 -68.6486 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.78988 .69655 m
.78978 .6928 L
s
.80539 .68939 m
.80527 .68564 L
s
.82108 .68214 m
.82096 .67839 L
s
.83697 .6748 m
.83684 .67105 L
s
.86935 .65984 m
.86921 .6561 L
s
.88585 .65222 m
.88571 .64847 L
s
.90256 .6445 m
.90241 .64076 L
s
.91949 .63669 m
.91933 .63294 L
s
.75944 .7106 m
.75935 .70686 L
s
.7445 .71751 m
.74441 .71376 L
s
.954 .62075 m
.95383 .617 L
s
.9716 .61262 m
.97142 .60887 L
s
gsave
.85571 .74232 -68.5361 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.21963 .22942 m
.97726 .40332 L
s
.25 Mabswid
.34762 .2588 m
.34752 .26505 L
s
gsave
.34782 .2463 -72.932 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.6198 .32127 m
.61988 .32752 L
s
gsave
.61965 .30877 -66.0622 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.87152 .37905 m
.87176 .3853 L
s
gsave
.87104 .36656 -69.3067 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.41772 .27489 m
.41769 .27864 L
s
.48642 .29066 m
.48642 .29441 L
s
.55377 .30612 m
.55379 .30987 L
s
.68456 .33614 m
.68463 .33989 L
s
.74807 .35072 m
.74817 .35446 L
s
.81038 .36502 m
.8105 .36877 L
s
.27609 .24238 m
.276 .24613 L
s
.93152 .39282 m
.93169 .39657 L
s
gsave
.61887 .24628 -68.9097 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.02041 .39623 m
.01039 .59918 L
s
.25 Mabswid
.01884 .42811 m
.02497 .42931 L
s
gsave
.00657 .42571 -79.25 -12.372 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.01545 .49665 m
.0216 .4978 L
s
gsave
.00316 .49436 -71 -12.3056 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.01202 .56617 m
.01817 .56726 L
s
gsave
-0.00029 .56399 -71 -12.2384 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.01816 .44174 m
.02185 .44246 L
s
.01749 .45541 m
.02117 .45612 L
s
.01681 .46912 m
.0205 .46982 L
s
.01613 .48287 m
.01982 .48356 L
s
.01477 .51048 m
.01846 .51116 L
s
.01408 .52434 m
.01777 .52502 L
s
.0134 .53824 m
.01709 .53891 L
s
.01271 .55219 m
.0164 .55285 L
s
.01951 .41452 m
.02319 .41525 L
s
.02018 .40096 m
.02386 .4017 L
s
.01133 .58019 m
.01502 .58084 L
s
.01063 .59425 m
.01433 .59489 L
s
gsave
-0.05828 .4829 -75.3125 -12.3056 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.02041 .39623 m
.01039 .59918 L
s
.01039 .59918 m
.73157 .72348 L
s
.73157 .72348 m
.72728 .53789 L
s
.72728 .53789 m
.02041 .39623 L
s
.21963 .22942 m
.97726 .40332 L
s
.97726 .40332 m
.98719 .60542 L
s
.98719 .60542 m
.21308 .45217 L
s
.21308 .45217 m
.21963 .22942 L
s
.02041 .39623 m
.01039 .59918 L
s
.01039 .59918 m
.21308 .45217 L
s
.21308 .45217 m
.21963 .22942 L
s
.21963 .22942 m
.02041 .39623 L
s
.72728 .53789 m
.97726 .40332 L
s
.97726 .40332 m
.98719 .60542 L
s
.98719 .60542 m
.73157 .72348 L
s
.73157 .72348 m
.72728 .53789 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
[ ] 0 setdash
.79724 .67828 m .79182 .49607 L .71754 .53626 L p 0 .415 .36 r
F P
0 g
s
.71754 .53626 m .72146 .71372 L .79724 .67828 L p 0 .415 .36 r
F P
0 g
s
.72146 .71372 m .71754 .53626 L .54632 .50196 L p 0 .7 .371 r
F P
0 g
s
.54632 .50196 m .71754 .53626 L .79182 .49607 L p 0 .889 .533 r
F P
0 g
s
.54632 .50196 m .54718 .68347 L .72146 .71372 L p 0 .7 .371 r
F P
0 g
s
.79724 .67828 m .72146 .71372 L .54718 .68347 L p 0 .902 .541 r
F P
0 g
s
.61948 .6461 m .54718 .68347 L .54632 .50196 L p 0 .384 .353 r
F P
0 g
s
.79182 .49607 m .61725 .45962 L .54632 .50196 L p 0 .889 .533 r
F P
0 g
s
.54632 .50196 m .61725 .45962 L .61948 .6461 L p 0 .384 .353 r
F P
0 g
s
.61725 .45962 m .79182 .49607 L .79258 .52169 L p 0 .701 .37 r
F P
0 g
s
.23962 .46717 m .23603 .60194 L .54705 .65713 L p .891 0 .371 r
F P
0 g
s
.54705 .65713 m .23603 .60194 L p .4105 .58041 L .689 0 .54 r
F P
0 g
s
.79258 .52169 m .79645 .65183 L p .64314 .49107 L 0 .701 .37 r
F P
0 g
s
.64314 .49107 m .79645 .65183 L .7717 .64725 L 0 .701 .37 r
F
.79724 .67828 m .61948 .6461 L .61725 .45962 L p F P
0 g
s
.54644 .52748 m .54705 .65713 L .77802 .53506 L p .499 0 .353 r
F P
0 g
s
.54705 .65713 m .54644 .52748 L .23962 .46717 L p .891 0 .371 r
F P
0 g
s
.77802 .53506 m .61916 .61902 L p .4105 .58041 L .689 0 .54 r
F P
0 g
s
.61916 .61902 m .54705 .65713 L p .4105 .58041 L .689 0 .54 r
F P
0 g
s
.79645 .65183 m .79724 .67828 L p .7717 .64725 L 0 .701 .37 r
F P
0 g
s
.61725 .45962 m .79258 .52169 L .64314 .49107 L 0 .701 .37 r
F
.23962 .46717 m .54644 .52748 L .61756 .48583 L p .709 0 .534 r
F P
0 g
s
.61756 .48583 m .77404 .39417 L p .41174 .44366 L .709 0 .534 r
F P
0 g
s
.23962 .46717 m .61756 .48583 L .41174 .44366 L .709 0 .534 r
F
.77802 .53506 m .77404 .39417 L .54644 .52748 L p .499 0 .353 r
F P
0 g
s
.54718 .68347 m .61948 .6461 L .79724 .67828 L p 0 .902 .541 r
F P
0 g
s
.44553 .46776 m .23603 .60194 L .23962 .46717 L p .425 0 .336 r
F P
0 g
s
.77404 .39417 m .44635 .32083 L .37277 .37291 L p .709 0 .534 r
F P
0 g
s
.37277 .37291 m .23962 .46717 L p .58978 .41934 L .709 0 .534 r
F P
0 g
s
.58978 .41934 m .77404 .39417 L .37277 .37291 L .709 0 .534 r
F
.37314 .34488 m .16614 .29976 L p .19556 .335 L 0 .701 .368 r
F P
0 g
s
.23962 .46717 m .44635 .32083 L .44553 .46776 L p .425 0 .336 r
F P
0 g
s
.44553 .46776 m .77802 .53506 L p .59106 .55813 L .689 0 .54 r
F P
0 g
s
.23603 .60194 m .3709 .51556 L p .59106 .55813 L .689 0 .54 r
F P
0 g
s
.3709 .51556 m .44553 .46776 L p .59106 .55813 L .689 0 .54 r
F P
0 g
s
.19556 .335 m .34154 .50989 L .37277 .37291 L 0 .701 .368 r
F
.37052 .5446 m .3709 .51556 L p .34154 .50989 L F P
0 g
s
.3709 .51556 m .37277 .37291 L p .34154 .50989 L 0 .701 .368 r
F P
0 g
s
.37277 .37291 m .37314 .34488 L p .19556 .335 L 0 .701 .368 r
F P
0 g
s
.44635 .32083 m .77404 .39417 L .77802 .53506 L p .903 0 .365 r
F P
0 g
s
.44536 .49769 m .44651 .29197 L .37314 .34488 L p 0 .315 .336 r
F P
0 g
s
.37314 .34488 m .37052 .5446 L .44536 .49769 L p 0 .315 .336 r
F P
0 g
s
.16614 .29976 m .37314 .34488 L .44651 .29197 L p 0 .889 .533 r
F P
0 g
s
.77802 .53506 m .44553 .46776 L .44635 .32083 L p .903 0 .365 r
F P
0 g
s
.16614 .29976 m .15902 .5046 L .37052 .5446 L p 0 .701 .368 r
F P
0 g
s
.44536 .49769 m .37052 .5446 L .15902 .5046 L p 0 .902 .541 r
F P
0 g
s
.22844 .45473 m .15902 .5046 L .16614 .29976 L p 0 .258 .321 r
F P
0 g
s
.44651 .29197 m .23431 .24359 L .16614 .29976 L p 0 .889 .533 r
F P
0 g
s
.16614 .29976 m .23431 .24359 L .22844 .45473 L p 0 .258 .321 r
F P
0 g
s
.23431 .24359 m .44651 .29197 L .44536 .49769 L p 0 .702 .365 r
F P
0 g
s
.15902 .5046 m .22844 .45473 L .44536 .49769 L p 0 .902 .541 r
F P
0 g
s
.44536 .49769 m .22844 .45473 L .23431 .24359 L p 0 .702 .365 r
F P
0 g
s
[ .01 .01 ] 0 setdash
.21963 .22942 m
.97726 .40332 L
s
.97726 .40332 m
.98719 .60542 L
s
.98719 .60542 m
.21308 .45217 L
s
.21308 .45217 m
.21963 .22942 L
s
.02041 .39623 m
.01039 .59918 L
s
.01039 .59918 m
.21308 .45217 L
s
.21308 .45217 m
.21963 .22942 L
s
.21963 .22942 m
.02041 .39623 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{291.188, 291.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005[0001Ja000`40O003h00OogooK7oo003oOom/
Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00
ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/
Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00
ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/
Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00
ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/
Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00
ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/
Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00
ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/
Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00
ogooK7oo003oOom/Ool00?moofaoo`00U7oo1P0017oo0`00BGoo0`00OWoo002DOol00`00Oomoo`03
Ool01000Oomoo`000goo00<007ooOol0Agoo00<007ooOol0OGoo002EOol00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`16Ool00`00Oomoo`1mOol008Yoo`P000Aoo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo04Ioo`03001oogoo07eoo`00Ugoo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol0AWoo00<007ooOol0OGoo002HOol01@00Oomoogoo00001Goo00<007ooOol0AGoo00<0
07oo0000OWoo001/Ool3000ZOol01000Oomoo`001Goo00<007ooOol0AGoo00<007oo0000OWoo001[
Ool20002Ool6000OOol00`00Oomoo`02Ool01000Oomoo`001Goo00<007ooOol0A7oo00D007ooOomo
o`0007eoo`00JWoo00<007ooOol01goo10007Goo00@007ooOol000Aoo`05001oogooOol00016Ool0
0`00Oomoo`03Ool00`00Oomoo`1jOol007Qoo`D001Uoo`8000Ioo`<004Ioo`<000=oo`<007]oo`00
Igoo00<007ooOol00Woo00@007ooOomoo`@000Qoo`H00>Uoo`00IWoo00<007ooOol00goo00H007oo
Ool0004:00020//40006Ool00`00Oomoo`04003VOol006Eoo`03001oogoo00Aoo`03001oo`000081
2P030002b`;;00@2b`D000Qoo`D00>5oo`00K7oo0P000`4:00<000;;0//02@;;100027oo1P00g7oo
001ROol00`00Oomoo`07Ool00`000@X12P020@X00`000//2b`0=0//40009Ool4003IOol0065oo`03
001oogoo00Moo`0300012P4:00<12P030002b`;;0142b`D000Qoo`D00=Aoo`00H7oo00<007ooOol0
1Woo0P001P4:00<000;;0//05P;;100027oo1@00d7oo001XOol01@000@X12P4:0000104:00<000;;
0//06P;;100017oo00<007ooOol00Woo1`00bGoo001MOol00`00Oomoo`07Ool00`000@X12P020@X0
0`000@X12P020@X00`000//2b`0N0//50008Ool40038Ool005aoo`03001oogoo00Moo`0300012P4:
00<12P0300012P4:00812P030002b`;;02<2b`@000Qoo`D00<=oo`00Fgoo00<007ooOol01goo00<0
004:0@X0104:00<0004:0@X00P4:00<000;;0//09`;;10002Goo1`00?Woo0`00Ngoo001TOol00`00
0@X12P0:0@X00`000//2b`0[0//50008Ool4000lOol01@00Oomoogoo0000NWoo001SOol00`000@X1
2P0;0@X00`000//2b`0`0//40005Ool00`00Oomoo`05000fOol00`00Oomoo`03Ool00`00Oomoo`1g
Ool005Qoo`03001oogoo00Ioo`8000P12P0300012P4:00<12P030002b`;;03@2b`@000Uoo`H0031o
o`03001oogoo00=oo`03001oogoo07Moo`00Egoo00<007ooOol01Woo00<0004:0@X0204:00<0004:
0@X00`4:00<000;;0//0>0;;1@0027oo1000;Woo00<007ooOol00goo00<007ooOol0Mgoo001FOol0
0`00Oomoo`06Ool00`000@X12P090@X00`000@X12P030@X00`000//2b`0m0//40008Ool5000YOol0
0`00Oomoo`03Ool00`00Oomoo`1gOol005ioo`0300012P4:00X12P0300012P4:00<12P030002b`;;
0442b`8000]oo`H002=oo`03001oogoo00=oo`03001oogoo07Moo`00Dgoo00<007ooOol01goo00<0
004:0@X04@4:00<000;;0//0@P;;00<007ooOol02Woo00<007ooOol010008Goo00<007ooOol00goo
00<007ooOol0Mgoo001BOol00`00Oomoo`07Ool00`000@X12P0A0@X00`000//2b`130//00`00Oomo
o`0AOol6000LOol01@00Oomoogoo0000NWoo001AOol00`00Oomoo`07Ool00`000@X12P0B0@X00`00
0//2b`130//00`00Oomoo`0FOol6000HOol3001kOol005]ooa012P0300012P4:00812P030002b`;;
04<2b`03001oogoo01Yoo`@009Aoo`00CWoo00<007ooOol02Woo00<0004:0@X03@4:00<0004:0@X0
0P4:00<000;;0//0@`;;00<007ooOol07Woo1@00Sgoo001=Ool00`00Oomoo`0;Ool00`000@X12P0=
0@X00`000@X12P020@X00`000//2b`130//00`00Oomoo`0POol00`00Oomoo`05002:Ool004aoo`03
001oogoo00aoo`0300012P4:00d12P0300012P4:00812P030002b`;;04<2b`03001oogoo02Moo`@0
08Moo`00Fgoo00<0004:0@X04P4:00<000;;0//0@`;;00<007ooOol0:goo1@00PWoo0019Ool00`00
Oomoo`0?Ool00`000@X12P0B0@X00`000//2b`130//00`00Oomoo`0`Ool5001mOol004Qoo`03001o
ogoo011oo`0300012P4:00d12P0300012P4:00812P030002b`;;04<2b`<003Aoo`L007Moo`00Agoo
00<007ooOol04Goo00<0004:0@X03@4:00<0004:0@X00P4:00<000;;0//0@`;;00<0070;L0/01@00
<7oo00<007ooOol01@00MGoo001KOol00`000@X12P0=0@X00`000@X12P020@X00`000//2b`130//0
0`00L0]`2`05L0/4000]Ool00`00Oomoo`04Ool5001`Ool004Aoo`03001oogoo01Aoo`0300012P4:
00d12P0300012P4:00812P030002b`;;04<2b`03001`2g0;00U`2`D003=oo`L003Qoo`H000Aoo`<0
02Eoo`00@goo00<007ooOol05Goo00<0004:0@X04P4:00<000;;0//0@`;;00<0070;L0/03W0;1000
<goo1@00=Woo00<007ooOol00goo00@007ooOol000=oo`03001oogoo029oo`00@Woo00<007ooOol0
5Goo00<0004:0@X04`4:00<000;;0//0@`;;00<0070;L0/04W0;1@00<goo1@00<Woo00<007ooOol0
17oo00<007ooOol00goo00<007ooOol08Goo001JOol00`000@X12P0C0@X00`000//2b`130//00`00
L0]`2`0GL0/4000`Ool00`00Oomoo`07000]Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`0QOol003moo`03001oogoo01Qoo`0300012P4:00h12P0300012P4:00812P030002b`;;04<2b`03
001`2g0;01]`2`@003=oo`D002aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo025oo`00
?goo00<007ooOol067oo00<0004:0@X03P4:00<0004:0@X00P4:00<000;;0//0@`;;00<0070;L0/0
7g0;1@00<goo1000:Goo00D007ooOomoo`0000Eoo`03001oogoo025oo`00?Woo00<007ooOol06Goo
00<0004:0@X03P4:00<0004:0@X00P4:00<000;;0//0@`;;00<0070;L0/0970;1000<goo1`008goo
00@007ooOol000Eoo`03001oogoo025oo`00?Goo00<007ooOol06Woo00<0004:0@X03P4:00<0004:
0@X00P4:00<000;;0//0@`;;00<0070;L0/0:70;1@00<Woo1@0077oo00<007ooOol00Woo00@007oo
Ool000Eoo`03001oogoo025oo`00FWoo00<0004:0@X04`4:00<000;;0//0@`;;00<0070;L0/0;G0;
1000;Woo00<007ooOol00Woo1@0067oo00@007ooOol000Aoo`05001oogooOol0000TOol003Yoo`03
001oogoo01eoo`0300012P4:01<12P030002b`;;04<2b`03001`2g0;035`2`D0039oo`H001Aoo`80
00Ioo`<002Eoo`00>Goo00<007ooOol07Woo00<0004:0@X03P4:00<0004:0@X00P4:00<000;;0//0
@`;;00<0070;L0/0=W0;1000<Woo1@00@Goo000hOol00`00Oomoo`0OOol00`000@X12P0>0@X00`00
0@X12P020@X00`000//2b`130//00`00L0]`2`0jL0/5000bOol5000lOol005Yoo`0300012P4:00h1
2P0300012P4:00812P030002b`;;04<2b`03001`2g0;03m`2`@0035oo`L003Moo`00=Goo00<007oo
Ool08Woo00<0004:0@X03P4:00<0004:0@X00P4:00<000;;0//0@`;;00<0070;L0/0@g0;1@00<Goo
1@00=7oo000dOol00`00Oomoo`0SOol00`000@X12P0C0@X00`000//2b`130//00`00L0]`2`18L0/4
000bOol5000_Ool003=oo`03001oogoo02Aoo`0300012P4:01<12P030002b`;;04<2b`03001`2g0;
04a`2`@0039oo`H002Yoo`00FWoo00<0004:0@X04`4:00<000;;0//0@`;;00<0070;L0/0D70;1@00
<Goo200097oo000`Ool00`00Oomoo`0WOol00`000@X12P0>0@X00`000@X12P020@X00`000//2b`13
0//00`00L0]`2`1EL0/4000_Ool00`00Oomoo`04000SOol002moo`03001oogoo02Qoo`0300012P4:
00h12P0300012P4:00812P030002b`;;04<2b`03001`2g0;05U`2`D002Yoo`03001oogoo00Aoo`D0
01ioo`00;Woo00<007ooOol0:Goo00<0004:0@X03@4:00<0004:0@X00`4:00<000;;0//0@`;;00<0
070;L0/0GW0;1000<Goo20005goo001JOol00`000@X12P0=0@X00`000@X12P030@X00`000//2b`13
0//00`00L0]`2`1RL0/5000aOol4000FOol002]oo`03001oogoo02aoo`0300012P4:01<12P030002
b`;;04<2b`03001`2g0;06M`2`80039oo`H0015oo`00:goo00@007ooOomoo`<002Qoo`0300012P4:
01<12P030002b`;;04<2b`03001`2g0;06Q`2`03001oogoo03Eoo`P000Yoo`00:goo0P001Goo00<0
07ooOol00`008Woo00<0004:0@X03@4:00<0004:0@X00`4:00<000;;0//0@`;;00<0070;L0/0J70;
00<007ooOol0>Woo10002Goo000[Ool00`00Oomoo`0:Ool00`00Oomoo`0NOol00`000@X12P0>0@X0
0`000@X12P020@X00`000//2b`140//00`00L0]`2`1XL0/00`00Oomoo`0nOol20007Ool002]oo`03
001oogoo00eoo`D001Uoo`0300012P4:00h12P0300012P4:00812P030002b`;;04@2b`03001`2g0;
06Q`2`03001oogoo03moo`03001oogoo00Eoo`007Goo1@002Goo00<007ooOol057oo10004goo00<0
004:0@X03P4:00<0004:0@X00P4:00<000;;0//0A0;;00<0070;L0/0J70;00<007ooOol0>Woo0P00
0goo00<007ooOol01Goo000ROol00`00Oomoo`06Ool2000KOol3000>Ool00`000@X12P0C0@X00`00
0//2b`140//00`00L0]`2`1XL0/00`00Oomoo`0hOol20005Ool00`00Oomoo`05Ool002=oo`03001o
ogoo00Eoo`03001oogoo01eoo`03001oogoo00<000Qoo`0300012P4:01<12P030002b`;;04@2b`03
001`2g0;06Q`2`03001oogoo04Moo`004goo200027oo00<007ooOol01Goo00<007ooOol08goo0P00
1Woo00<0004:0@X04`4:00<000;;0//0A0;;00<0070;L0/0J70;00<007ooOol0=7oo0P004Goo000S
Ool00`00Oomoo`05Ool00`00Oomoo`0WOol5000@0@X00`000@X12P020@X00`000//2b`140//00`00
L0]`2`1XL0/00`00Oomoo`0bOol2000;Ool00`00Oomoo`05Ool0029oo`03001oogoo00Ioo`03001o
ogoo02]oo`0300012P4:00h12P0300012P4:00812P030002b`;;04@2b`03001`2g0;06Q`2`03001o
ogoo03moo`03001oogoo00Eoo`007Woo10002Goo0`00:goo00<0004:0@X03P4:00<0004:0@X00P4:
00<000;;0//0A0;;00<0070;L0/0J70;00<007ooOol0;goo0P003Woo00<007ooOol01Goo000NOol0
0`00Oomoo`09Ool00`00Oomoo`0/Ool00`000@X12P0>0@X00`000@X12P020@X00`000//2b`140//0
0`00L0]`2`1XL0/00`00Oomoo`0]Ool2000@Ool00`00Oomoo`05Ool001moo`03001oogoo00Qoo`03
001oogoo02aoo`0300012P4:01<12P030002b`;;04@2b`03001`2g0;06Q`2`03001oogoo04Moo`00
7goo1@001Woo00<007ooOol0;7oo00<0004:0@X04`4:00<000;;0//0A0;;00<0070;L0/0J70;00<0
07ooOol0:Goo0P0077oo000ZOol3000/Ool00`000@X12P0>0@X00`000@X12P020@X00`000//2b`14
0//00`00L0]`2`1XL0/00`00Oomoo`0XOol00`00Oomoo`0LOol002Yoo`03001oogoo02aoo`030001
2P4:00h12P0300012P4:00812P030002b`;;04@2b`03001`2g0;06Q`2`03001oogoo02Moo`03001o
ogoo01Ioo`03001oogoo00Aoo`00:Woo00<007ooOol0;7oo00<0004:0@X03P4:00<0004:0@X00P4:
00<000;;0//0A0;;00<0070;L0/0J70;00<007ooOol08goo0P006goo00<007ooOol017oo000ZOol0
0`00Oomoo`0/Ool00`000@X12P0>0@X300020@X00`000//2b`140//00`00L0]`2`1XL0/00`00Oomo
o`0ROol00`00Oomoo`0KOol00`00Oomoo`04Ool002Yoo`03001oogoo02aoo`0300012P4:00d12P80
00812PH004<2b`03001`2g0;06Q`2`03001oogoo025oo`03001oogoo01aoo`03001oogoo00Aoo`00
:Woo0P00;Goo00<0004:0@X02`4:0P00104:00<000>A0i402000?P;;00<0070;L0/0J70;00<007oo
Ool07Goo0P00:7oo000ZOol00`00Oomoo`0/Ool00`000@X12P0@0@X00`000i43T@070i47000i0//0
0`00L0]`2`1XL0/00`00Oomoo`0LOol00`00Oomoo`0XOol002Yoo`03001oogoo02aoo`0300012P4:
00P12P0300012P4:00<12P8000d3T@800083T@D003@2b`03001`2g0;06Q`2`03001oogoo01]oo`03
001oogoo029oo`03001oogoo00Aoo`00:Woo00<007ooOol0;7oo00<0004:0@X01`4:00<0004:0@X0
0`4:00<000>A0i4050>A00<000>A00001000;`;;00<0070;L0/0JG0;00<007ooOol05goo0P009Woo
00<007ooOol017oo0002Ool8000POol2000]Ool00`000@X12P060@X00`000@X12P030@X00`000i43
T@0K0i46000Z0//4001XL0/00`00Oomoo`0FOol00`00Oomoo`0VOol00`00Oomoo`04Ool000=oo`03
001oogoo00=oo`03001oogoo01ioo`03001oogoo02aoo`0300012P4:00X12P800283T@L002D2b`04
001H4EPAF145001SL0/00`00Oomoo`0EOol00`00Oomoo`0WOol00`00Oomoo`04Ool000Aoo`03001o
ogoo009oo`03001oogoo01ioo`03001oogoo02]oo`0300012P4:00@12P0300012P4:00<12P030003
T@>A02P3T@H00202b`03001H4EPA00IH4@D005i`2`03001oogoo015oo`8003=oo`0017oo00<007oo
Ool08goo00<007ooOol0:goo00<0004:0@X00`4:00<0004:0@X00P4:0P00;P>A00<000>A0i401@00
6`;;00<005PAF1402ePA1@00FG0;00<007ooOol047oo00<007ooOol0<goo0005Ool00`00Oomoo`0E
Ool3000:Ool00`00Oomoo`0[Ool00`000@X12P020@X00`000@X12P020@X00`000i43T@0d0i47000F
0//00`00F15H4@0@F145001DL0/00`00Oomoo`0?Ool00`00Oomoo`0dOol000Ioo`03001oogoo01=o
o`05001oogooOol00009Ool2000/Ool00`000@X12P060@X00`000i43T@0i0i48000A0//00`00F15H
4@0EF145001?L0/00`00Oomoo`0;Ool2000bOol00`00Oomoo`04Ool000Moo`03001oogoo015oo`03
001oogoo00=oo`03001oogoo00Ioo`03001oogoo02]oo`<000@12P800483T@L000`2b`03001H4EPA
01YH4@D004Y`2`03001oogoo00Yoo`03001oogoo039oo`03001oogoo00Aoo`000Woo00<007ooOol0
0Woo00<007ooOol04Goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0:goo00<0004:0@X0
0`4:00<000>A0i40B@>A1@001`;;00<005PAF1407ePA1P00A70;00<007ooOol02Goo00<007ooOol0
<goo00<007ooOol017oo0002Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00
Oomoo`06Ool00`00Oomoo`0ZOol200040@X00`000i43T@1=0i400`000i40000400020//00`00F15H
4@0UF145000oL0/4000nOol00`00Oomoo`04Ool0009oo`P0015oo`03001oogoo00=oo`03001oogoo
00Eoo`<002aoo`0300012P4:008005H3T@@002aH4@D003Y`2`040002b`;;0//20002Ool2000oOol0
01]oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo02Qoo`80009oo`0300012P0005T3T@03
001H4@0000@002eH4@D003E`2`030002b`;;0082b`<0045oo`006goo00<007ooOol00goo00<007oo
Ool01Goo00<007ooOol09goo00<007ooOol00Woo0P00F0>A0P002EPA1000;5PA1@00<70;00<000;;
0//00P;;00<007ooOol0>goo00<007ooOol00goo000LOol01@00Oomoogoo000027oo00<007ooOol0
9Woo00<007ooOol00goo00<000>A0i40EP>A00<005PAF1403ePA0`00;5PA1@00:g0;00<000;;0//0
0P;;00<007ooOol0>goo00<007ooOol00goo000MOol30009Ool00`00Oomoo`0`Ool5001>0i42000E
F1401000F15H4EPA0`00:UPA1@009W0;00<000;;0//00P;;00<007ooOol0>goo00<007ooOol00goo
000YOol2000TOol00`00Oomoo`0?Ool500170i42000NF1400`00F15H4@0/F146000PL0/00`000//2
b`020//00`00Oomoo`0kOol00`00Oomoo`03Ool002Uoo`03001oogoo029oo`03001oogoo01Eoo`H0
0403T@03001H4EPA025H4@@002iH4@D001]`2`030002b`;;0082b`03001oogoo045oo`00:Goo00<0
07ooOol08Goo00<007ooOol077oo1@00>@>A0P00:UPA0`00;UPA1@005W0;00<000;;0//00P;;00<0
07ooOol0@Goo000YOol00`00Oomoo`0MOol2000VOol5000c0i400`00F15H4@0]F1420002F143000/
F145000AL0/00`000//2b`020//00`00Oomoo`11Ool002Uoo`8001eoo`03001oogoo02Moo`04000d
2S@:=0X6000[0i42000gF1400`00F15H4@03000[F145000<L0/00`000//2b`020//00`00Oomoo`0k
Ool00`00Oomoo`03Ool002Uoo`03001oogoo01]oo`03001oogoo02Qoo`03000d2S@:00Ld2PD002D3
T@03001H4EPA03eH4@03001H4EPA02eH4@D000M`2`030002b`;;0082b`03001oogoo03]oo`03001o
ogoo00=oo`00:Goo00<007ooOol0AWoo00<003@:=0X033@:1@007P>A0P00A5PA1000;EPA1@000W0;
00<000;;0//00P;;00<007ooOol0>goo00<007ooOol00goo000YOol00`00Oomoo`0HOol2000/Ool0
0`00=0Xd2P0A=0X5000G0i42001<F143000]F14300040//00`00Oomoo`0kOol00`00Oomoo`03Ool0
02Uoo`03001oogoo01Moo`03001oogoo02aoo`03000d2S@:01Hd2PH00103T@03001H4EPA04mH4@03
001H4EPA00<002IH4@8000H2b`03001oogoo045oo`00:Goo0P005goo00<007ooOol0;Goo00<003@:
=0X06c@:1P002@>A0P00F5PA0P008UPA0P0020;;00<007ooOol0@Goo000YOol00`00Oomoo`16Ool0
0`00=0Xd2P0I=0X20006F14500030i400`00F15H4@1LF144000JF142000:0//00`00Oomoo`0kOol0
0`00Oomoo`03Ool002Uoo`03001oogoo01=oo`80035oo`03000d2S@:01Ld2P8000eH4@<006EH4@@0
01=H4@030002b`;;00X2b`03001oogoo03]oo`03001oogoo00=oo`00:Goo00<007ooOol04Woo00<0
07ooOol0<Goo00<003@:=0X05S@:00<005PAF140O5PA0`002ePA0P003@;;00<007ooOol0>goo00<0
07ooOol00goo000JOol5000:Ool2000BOol00`00Oomoo`0bOol00`00=0Xd2P0D=0X20022F1400`00
F15H4@030003F142000?0//00`00Oomoo`0kOol00`00Oomoo`03Ool001moo`03001oogoo00Ioo`80
04Qoo`03000d2S@:01<d2P03001H4EPA08QH4@<00142b`03001oogoo045oo`0087oo00<007ooOol0
1Goo0P0047oo00<007ooOol0=Goo00<003@:=0X04C@:0P00RUPA0P000P;;10003@;;00<007ooOol0
@Goo000POol00`00Oomoo`05Ool2000?Ool00`00Oomoo`0fOol00`00=0Xd2P0@=0X00`00F15H4@28
F142000;0//400060//00`00Oomoo`11Ool0021oo`03001oogoo00Eoo`8000ioo`03001oogoo03Mo
o`03000d2S@:00hd2P8008UH4@8001<2b`<000030//007oo03eoo`03001oogoo009oo`007goo00<0
07ooOol01Woo0`00Agoo00<003@:=0X033@:0P00RUPA00<000;;0//05P;;0P0000Aoo`00000003Yo
o`03001oogoo009oo`006goo10002Goo00<007ooOol02Goo0P00>goo00<003@:=0X033@:00<005PA
F140R5PA0P006P;;00<007ooOol00Woo0P00>7oo00<007ooOol00Woo000KOol00`00Oomoo`0:Ool0
0`00Oomoo`08Ool00`00Oomoo`0kOol00`00=0Xd2P0:=0X20029F142000L0//00`00Oomoo`06Ool4
000bOol00`00Oomoo`02Ool001aoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo03aoo`03
000d2S@:00Td2P03001H4EPA08MH4@8001h2b`03001oogoo00aoo`<0039oo`0077oo1@001goo0P00
Agoo00<003@:=0X01c@:0P00R5PA0P0080;;00<007ooOol03goo00@007ooOomoo`<002]oo`00:7oo
00<007ooOol017oo0P00@7oo00<003@:=0X01S@:00<005PAF140QUPA0P008P;;00<007ooOol05Woo
00<007ooOol00`0087oo00<007ooOol00Woo000XOol00`00Oomoo`03Ool00`00Oomoo`10Ool00`00
=0Xd2P04=0X20027F142000T0//00`00Oomoo`0LOol00`00Oomoo`0MOol00`00Oomoo`02Ool002Qo
o`03001oogoo009oo`03001oogoo045oo`03000d2S@:008d2P8008QH4@030002b`;;02D2b`03001o
ogoo01ioo`D001Qoo`03001oogoo009oo`00:7oo00<007oo0000AWoo00D003@:=0Xd2P0008QH4@80
02P2b`03001oogoo02Eoo`<001=oo`03001oogoo009oo`00:7oo0P00Agoo00@003@:000008MH4@80
02X2b`03001oogoo02Qoo`03001oogoo00<0019oo`00:7oo0`00AWoo0P00QePA0P00;0;;00<007oo
Ool0;Woo00<007ooOol03goo000[Ool00`00Oomoo`030010Ool00`00F15H4@24F142000^0//00`00
Oomoo`0bOol4000:Ool0035oo`03001oogoo045oo`H007]H4@800302b`03001oogoo03Qoo`@000Ao
o`00=Goo1000@Woo1@00M5PA0P00<P;;00<007ooOol0>7oo0P001Woo000kOol40011Ool6001]F140
0`000//2b`0b0//00`00Oomoo`0fOol30007Ool0045oo`D0041oo`H006EH4@8002<2b`030J/2b`;;
00l2b`03001oogoo03Aoo`<000Uoo`00B7oo1000@7oo1@00GUPA0P00=`;;00<007ooOol0<7oo1000
37oo001>Ool30010Ool6001FF142000i0//00`00Oomoo`0_Ool200000goo001oo`0<Ool0055oo`80
009oo`<003moo`H004iH4@8000030H/000;;03P2b`03001oogoo02]oo`03001oo`000080011oo`00
F7oo00<007ooOol00`00?goo1@00AePA0P000`6;00<000;;0//0=`;;00<007ooOol0:goo0`004Woo
001NOol01000Oomoogoo0`00?Goo1P00?ePA0P001@6;00<000;;0//0=`;;00<007ooOol0:Goo0`00
57oo001UOol00`00Oomoo`03000mOol6000gF14200070H/00`000//2b`0g0//00`00Oomoo`0UOol0
0`00Ool00002000FOol006]oo`03001oogoo041oo`D0031H4@8000T1R`030002b`;;03L2b`03001o
ogoo02Eoo`<001Qoo`00KWoo1@00@7oo1P00:EPA00<0006;0H/02@6;00<000;;0//0=`;;00<007oo
Ool08goo0`006Woo001eOol40010Ool6000QF142000<0H/00`000//2b`0g0//00`00Oomoo`0POol3
000MOol007]oo`D003moo`D001YH4@8000h1R`030002b`;;03L2b`03001oogoo01ioo`@001ioo`00
PWoo1000?Woo1P004UPA0P003`6;1@00;@;;00<1Z`;;0//01P;;00<007ooOol06Woo00<007oo0000
0P008Goo0028Ool3000oOol6000:F142000?0H/200050i46000`0//00`00Oomoo`0JOol3000SOol0
08]oo`04001oogooOol3000nOol50003F142000?0H/2000=0i46000Z0//00`00Oomoo`0HOol3000U
Ool0099oo`03001oogoo00<003eoo`<000l1R`8001D3T@D002D2b`03001oogoo01Eoo`@002Moo`00
V7oo00<007ooOol00`00>Goo00<0006;0H/02`6;0P0070>A1P007`;;00<007ooOol057oo0`003goo
0`001Goo0`003goo002NOol20002Ool3000bOol00`000H/1R`090H/2000T0i46000I0//00`00Oomo
o`0?Ool00`00Ool00002000COol00`00Oomoo`03Ool01@00Oomoogoo00003Woo002UOol00`00Oomo
o`0_Ool00`000H/1R`080H/00`000i43T@0Z0i46000C0//00`00Oomoo`0?Ool4000DOol00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00:Qoo`@002]oo`030001R`6;00H1R`8003<3T@H0
00d2b`03001oogoo00eoo`@001Ioo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00]oo`00
[goo100097oo00<0006;0H/0106;0P00>`>A1@0020;;00<007ooOol02Woo0`006Woo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol02goo002eOol4000NOol00`000H/1R`020H/200120i460002
0//00`00Oomoo`09Ool2000LOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00;ao
o`@001Moo`030001R`6;008004X3T@<000Moo`03001oo`00008001eoo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00]oo`00`Woo0`004Woo0`00B`>A0P002Goo0P0087oo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol02goo0035Ool00`00Oomoo`03000<Ool00`000i43T@190i420009
Ool2000QOol20005Ool01@00Oomoogoo00003Woo003;Ool20002Ool30009Ool600100i420008Ool3
000TOol00`00Oomoo`04Ool3000?Ool00=9oo`03001oogoo00<000Uoo`D003T3T@8000Qoo`<003mo
o`00f7oo00@007ooOomoo`<000Moo`H00343T@8000Moo`@0045oo`00ggoo00<007ooOol02Woo1P00
:@>A0P0017oo00@007ooOomoo`8004Aoo`00hWoo100037oo1@008P>A0P001Woo00<007oo00000P00
4goo0`00;goo003YOol4000:Ool6000J0i420008Ool3000DOol01@00Oomoogoo0000;Woo003_Ool4
000:Ool6000B0i420005Ool00`00Ool00002000FOol00`00Oomoo`03Ool00`00Oomoo`0[Ool00?Eo
o`D000Uoo`D000/3T@8000Moo`<001Qoo`03001oogoo00=oo`03001oogoo02]oo`00o7oo0`002Goo
1P000`>A0P001goo0`006Woo00<007ooOol00goo00<007ooOol0:goo003oOol00`00Oomoo`030009
Ool30002Ool01000Oomoogoo0`007Goo00<007ooOol00goo00<007ooOol0:goo003oOol6Ool01000
Oomoogoo0`001goo00<007ooOol00P007goo00<007ooOol00goo00<007ooOol0:goo003oOol=Ool0
0`00Oomoo`03000017oo000000008Goo00<007ooOol00goo00<007ooOol0:goo003oOolCOol2000T
Ool01@00Oomoogoo0000;Woo003oOoljOol3000_Ool00?moofaoo`00ogoo8Woo0`001Goo0`00?goo
003oOolSOol00`00Oomoo`03Ool01@00Oomoogoo0000?Woo003oOolSOol00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`0kOol00?mooaMoo`P000Aoo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo03]oo`00ogoo8goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0>goo003oOolS
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0kOol00?moob=oo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo03]oo`00ogoo8goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool0>goo003oOolROol20005Ool01@00Oomoogoo0000?Woo003oOolSOol00`00Oomoo`04Ool30008
Ool30003Ool4000]Ool00?moocIoo`03001oogoo00=oo`03001oogoo02eoo`00ogoo=goo00D007oo
Oomoo`00031oo`00ogoo>7oo00<007oo0000<Goo003oOoliOol2000aOol00?moocUoo`80035oo`00
ogoo>7oo00@007ooOol0031oo`00ogoo>7oo00@007ooOol0031oo`00ogoo=goo00<007ooOol00Woo
00<007ooOol0;Goo003oOoleOol40002Ool4000]Ool00?moofaoo`00ogooK7oo003oOom/Ool00?mo
ofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo
003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?mo
ofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo
003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?mo
ofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo
003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?mo
ofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo
003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?mo
ofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo
003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?mo
ofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo003oOom/Ool00?moofaoo`00ogooK7oo
003oOom/Ool00001\
\>"],
  ImageRangeCache->{{{0, 362.938}, {362.938, 0}} -> {-0.113157, -0.0565814, 
  0.00383387, 0.00383387}}]
}, Open  ]],

Cell["Computing the force and torque  : manual segmentation", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In this mode the segmentation of the destination object is set manually by \
defining the segmentation parameter n={8,8,8} and using it in  \
\"radFldEnrFrc",
  StyleBox["\"",
    FontWeight->"Bold"],
  " and \"radFldEnrTrq\". This allows a control of the memory but one must \
increase n gradually to check for the stability of the computed  force and \
torque. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(n = {8, 8, 8}; \n\n
    Print\ [\ "\<Force & Torque Computation between magnets \>"]; \n\t\t\n
    f = {radFldEnrFrc[g1, g2, "\<Fx\>", n], \ \n\t\t
        radFldEnrFrc[g1, g2, "\<Fy\>", n], \n\t\t
        radFldEnrFrc[g1, g2, "\<Fz\>", n]}; \n
    Print\ [\ "\<{Fx, Fy, Fz} = \>", N[f, 3], "\< N\>"]; \n\n
    c = {10, \(-20\), 5}; \n
    t = \ {radFldEnrTrq[g1, g2, "\<tx\>", c, n], \n\t\t
        radFldEnrTrq[g1, g2, "\<ty\>", c, n], \n\t\t
        radFldEnrTrq[g1, g2, "\<tz\>", c, n]}; \n
    Print\ [\ "\<{Tx, Ty, Tz} = \>", N[t, 3], "\< Nmm  w. resp. to Point \>", 
      c]; \)], "Input"],

Cell[BoxData[
    \("Force & Torque Computatio between magnets "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"{Fx, Fy, Fz} = \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["6.97744395233861069`*^-10",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], ",", 
            RowBox[{"-", 
              StyleBox["3.87702330555573304`*^-9",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}], ",", 
            RowBox[{"-", 
              StyleBox["40.7829739102974464`",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}]}], "}"}], "\[InvisibleSpace]", 
        "\<\" N\"\>"}],
      SequenceForm[ 
      "{Fx, Fy, Fz} = ", {
        6.9774439523386117*^-10, -3.8770233055557335*^-09,
         -40.78297391029745}, " N"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"{Tx, Ty, Tz} = \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["407.899781036864172`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], ",", 
            RowBox[{"-", 
              StyleBox["407.895921103102576`",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}], ",", 
            StyleBox["7.78067813103470307`*^-9",
              StyleBoxAutoDelete->True,
              PrintPrecision->3]}], "}"}], "\[InvisibleSpace]", 
        "\<\" Nmm  w. resp. to Point \"\>", "\[InvisibleSpace]", 
        \({10, 10, 10}\)}],
      SequenceForm[ 
      "{Tx, Ty, Tz} = ", {407.89978103686417, -407.89592110310258, 
        7.7806781310347035*^-09}, " Nmm  w. resp. to Point ", {10, 10, 10}],
      Editable->False]], "Print"]
}, Open  ]],

Cell["Computing the force and torque  : automatic segmentation", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
In this mode the segmentation of the destination object is set automatically  \
by calling  \"radFldCmpPrc[PrcForce->1,PrcTorque->5]\". During computation \
Radia will automatically increase the subdivision until the computation is \
stable or until it runs out of memory. The tuning between the precision and \
the memory requirement is not easy. This is particularly annoying on the \
Macintosh platform where one may have to reboot the computer if Radia.exe \
runs out of memory. For these reasons, this is not the recommended methods of \
computation except when the destination object is complexe and made of many \
different sub-objects of different sizes . \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(radFldCmpPrc[PrcForce -> 1, PrcTorque -> 5]; \n\n
    Print\ [\ "\<Force & Torque Computation between magnets \>"]; \n\t\t\n
    f = {radFldEnrFrc[g1, g2, "\<Fx\>"], \ \n\t\t
        radFldEnrFrc[g1, g2, "\<Fy\>"], \n\t\t
        radFldEnrFrc[g1, g2, "\<Fz\>"]}; \n
    Print\ [\ "\<{Fx, Fy, Fz} = \>", N[f, 3], "\< N\>"]; \n\n
    c = {10, 10, 10}; \n
    t = \ {radFldEnrTrq[g1, g2, "\<tx\>", c], \n\t\t
        radFldEnrTrq[g1, g2, "\<ty\>", c], \n\t\t
        radFldEnrTrq[g1, g2, "\<tz\>", c]}; \n
    Print\ [\ "\<{Tx, Ty, Tz} = \>", N[t, 3], "\< Nmm  w. resp. to Point \>", 
      c]; \)], "Input"],

Cell[BoxData[
    \("Force & Torque Computatio between magnets "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"{Fx, Fy, Fz} = \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["5.98897320625013662`*^-10",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], ",", 
            RowBox[{"-", 
              StyleBox["3.87161236403699149`*^-9",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}], ",", 
            RowBox[{"-", 
              StyleBox["41.8461069424087384`",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}]}], "}"}], "\[InvisibleSpace]", 
        "\<\" N\"\>"}],
      SequenceForm[ 
      "{Fx, Fy, Fz} = ", {
        5.9889732062501366*^-10, -3.8716123640369915*^-09,
         -41.846106942408738}, " N"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"{Tx, Ty, Tz} = \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["348.268970966016766`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], ",", 
            RowBox[{"-", 
              StyleBox["408.206055594594641`",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}], ",", 
            RowBox[{"-", 
              StyleBox["1.47413366772146714`",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}]}], "}"}], "\[InvisibleSpace]", 
        "\<\" Nmm  w. resp. to Point \"\>", "\[InvisibleSpace]", 
        \({10, 10, 10}\)}],
      SequenceForm[ 
      "{Tx, Ty, Tz} = ", {
        348.26897096601675, -408.20605559459466, -1.4741336677214671}, 
        " Nmm  w. resp. to Point ", {10, 10, 10}],
      Editable->False]], "Print"]
}, Open  ]],

Cell["Inverse Computation", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Here we swap the source and destiantion objects for the force and torque \
computation. The interaction energy and force is now computed on the green \
magnets  while the red magnet is the source. As expected,  the force and \
torque are (nearly) equal to those computed previously but with opposite \
signs.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(n = {8, 8, 8}; \n\n
    Print\ [\ "\<Force & Torque Computatio between magnets \>"]; \n\t\t\n
    f = {radFldEnrFrc[g2, g1, "\<Fx\>", n], \ \n\t\t
        radFldEnrFrc[g2, g1, "\<Fy\>", n], \n\t\t
        radFldEnrFrc[g2, g1, "\<Fz\>", n]}; \n
    Print\ [\ "\<{Fx, Fy, Fz} = \>", N[f, 3], "\< N\>"]; \n\n
    c = {10, 10, 10}; \n
    t = \ {radFldEnrTrq[g2, g1, "\<tx\>", c, n], \n\t\t
        radFldEnrTrq[g2, g1, "\<ty\>", c, n], \n\t\t
        radFldEnrTrq[g2, g1, "\<tz\>", c, n]}; \n
    Print\ [\ "\<{Tx, Ty, Tz} = \>", N[t, 3], "\< Nmm  w. resp. to Point \>", 
      c]; \)], "Input"],

Cell[BoxData[
    \("Force & Torque Computatio between magnets "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"{Fx, Fy, Fz} = \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"-", 
              StyleBox["6.84885246232598277`*^-10",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}], ",", 
            StyleBox["2.30569048383145602`*^-9",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], ",", 
            StyleBox["39.4284373366384812`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3]}], "}"}], "\[InvisibleSpace]", 
        "\<\" N\"\>"}],
      SequenceForm[ 
      "{Fx, Fy, Fz} = ", {-6.8488524623259829*^-10, 2.3056904838314561*^-09, 
        39.428437336638481}, " N"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"{Tx, Ty, Tz} = \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"-", 
              StyleBox["394.283559758388779`",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}], ",", 
            StyleBox["394.284011504051079`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], ",", 
            RowBox[{"-", 
              StyleBox["1.15705042339566865`*^-8",
                StyleBoxAutoDelete->True,
                PrintPrecision->3]}]}], "}"}], "\[InvisibleSpace]", 
        "\<\" Nmm  w. resp. to Point \"\>", "\[InvisibleSpace]", 
        \({10, 10, 10}\)}],
      SequenceForm[ 
      "{Tx, Ty, Tz} = ", {-394.28355975838878, 
        394.28401150405108, -1.1570504233956686*^-08}, 
        " Nmm  w. resp. to Point ", {10, 10, 10}],
      Editable->False]], "Print"]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{722, 739},
WindowMargins->{{118, Automatic}, {Automatic, 15}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
Magnification->1.25,
StyleDefinitions -> "Classroom.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 129, 3, 50, "Title",
  Evaluatable->False],
Cell[1841, 54, 98, 5, 62, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1964, 63, 79, 2, 65, "Section",
  Evaluatable->False],
Cell[2046, 67, 1512, 32, 240, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3595, 104, 85, 2, 65, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3705, 110, 77, 4, 74, "Input"],
Cell[3785, 116, 358, 7, 28, "Print"],
Cell[4146, 125, 126, 2, 47, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4321, 133, 527, 8, 324, "Input"],
Cell[4851, 143, 39309, 1200, 374, 18869, 943, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[44175, 1346, 120, 2, 65, "Section",
  Evaluatable->False],
Cell[44298, 1350, 395, 9, 69, "Text"],

Cell[CellGroupData[{
Cell[44718, 1363, 617, 12, 305, "Input"],
Cell[45338, 1377, 77, 1, 28, "Print"],
Cell[45418, 1380, 819, 21, 30, "Print"],
Cell[46240, 1403, 872, 20, 49, "Print"]
}, Open  ]],
Cell[47127, 1426, 123, 2, 65, "Section",
  Evaluatable->False],
Cell[47253, 1430, 688, 10, 145, "Text"],

Cell[CellGroupData[{
Cell[47966, 1444, 625, 12, 305, "Input"],
Cell[48594, 1458, 77, 1, 28, "Print"],
Cell[48674, 1461, 820, 21, 30, "Print"],
Cell[49497, 1484, 907, 22, 47, "Print"]
}, Open  ]],
Cell[50419, 1509, 86, 2, 65, "Section",
  Evaluatable->False],
Cell[50508, 1513, 332, 6, 69, "Text"],

Cell[CellGroupData[{
Cell[50865, 1523, 612, 12, 305, "Input"],
Cell[51480, 1537, 77, 1, 28, "Print"],
Cell[51560, 1540, 776, 19, 30, "Print"],
Cell[52339, 1561, 916, 22, 49, "Print"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

